import xbmc
import xbmcaddon

import sys
sys.path.append('/storage/.kodi/addons/virtual.rpi-tools/lib')

import os
os.environ['LG_WD'] = '/storage/.kodi/temp'

from gpiozero import LEDBoard

addon = xbmcaddon.Addon()
addon_id = addon.getAddonInfo('id')
addon_version = addon.getAddonInfo('version')

def log(msg, level=xbmc.LOGINFO):
    xbmc.log('[%s %s] %s' % (addon_id, addon_version, msg), level=level)


class RpiLeds(object):
    def __init__(self):
        self.LEDS = LEDBoard(pause=18, play=14, record=15)
        '''
            Pinout see https://pinout.xyz/pinout/ground#:~:text=The%20Ground%20pins%20on%20the,supply%20pin%20that%20you%20use

            18: LED_PAUSE      # Pin 12
            14: LED_PLAY       # Pin 8
            15: LED_RECORD     # Pin 10
        '''

        for led in self.LEDS: led.off()
        log('GPIO pins initialized')

    def free_up(self):
        for led in self.LEDS: led.close()


class EventLogger(xbmc.Monitor):
    def __init__(self):
        xbmc.Monitor.__init__(self)
        self.DeviceLeds = RpiLeds()
        log('Event logger started')

    def onNotification(self, sender, method, data):
        log('Event notified: %s, sender: %s, data: %s' % (method, sender, data))
        if method == 'Player.OnPlay': self.DeviceLeds.LEDS.play.on()
        elif method == 'Player.OnPause': self.DeviceLeds.LEDS.pause.on()
        elif method == 'Player.OnResume': self.DeviceLeds.LEDS.pause.off()
        elif method == 'Player.OnStop':
            self.DeviceLeds.LEDS.play.off()
            self.DeviceLeds.LEDS.pause.off()
        else: log('Event discarded')

    def logEvents(self):
        while not self.abortRequested(): self.waitForAbort(1000)
        self.DeviceLeds.free_up()


if __name__ == '__main__':
    Logger = EventLogger()
    Logger.logEvents()
    log('Event logger stopped')
    del Logger
